#
# spec file for package plymouth
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# plymouth's X11 renderer adds many GTK3 packages to the build cycle,
# it is not used in the production environment.
%bcond_with x11_renderer

%global soversion 5
%define plymouthdaemon_execdir %{_sbindir}
%define plymouthclient_execdir %{_bindir}
%define plymouth_libdir %{_libdir}
%define plymouth_initrd_file /boot/initrd-plymouth.img

Name:           plymouth
Version:        0.9.5+git20190908+3abfab2
Release:        5.3
Summary:        Graphical Boot Animation and Logger
License:        GPL-2.0-or-later
Group:          System/Base
URL:            http://www.freedesktop.org/wiki/Software/Plymouth
Source0:        %{name}-%{version}.tar.xz
Source1:        boot-duration
# PATCH-FIX-OPENSUSE plymouth-dracut-path.patch tittiatcoke@gmail.com -- Prefix is /usr/sbin and /usr/bin
Patch0:         plymouth-dracut-path.patch
# PATCH-FIX-OPENSUSE plymouth-some-greenish-openSUSE-colors.patch bnc#886148 fcrozat@suse.com -- To use suse colors in tribar.
Patch1:         plymouth-some-greenish-openSUSE-colors.patch
# PATCH-FIX-OPENSUSE plymouth-correct-runtime-dir.patch tittiatcoke@gmail.com -- Make sure the runtime directory is /run and not /var/run
Patch2:         plymouth-correct-runtime-dir.patch
# PATCH-FIX-UPSTREAM plymouth-manpages.patch bnc#871419 idoenmez@suse.de  -- Fix man page installation
Patch3:         plymouth-manpages.patch
# PATCH-FIX-OPENSUSE plymouth-avoid-umount-hanging-shutdown.patch bnc#1105688, bnc#1129386, bnc#1134660 qzhao@opensuse.org -- Drop grantpt() to avoid system failed to unmount /var during shutdown.
Patch4:         plymouth-avoid-umount-hanging-shutdown.patch
# PATCH-FIX-SLE plymouth-no-longer-modify-conf-to-drop-isopensuse-macro.patch qzhao@suse.com  jsc#SLE-11637 -- plymouth will use plymouthd.defaults instead of plymouth.conf to close the leap gap.
Patch5:         plymouth-no-longer-modify-conf-to-drop-isopensuse-macro.patch
# PATCH-FIX-UPSTREAM plymouth_add_RemainAfterExit_yes_to_plymouth_systemd_service.patch bnc#1177072 - Backport from upstream, to ensure all plymouth's systemd unit files to only run once, either during boot or during shutdown/restart.
Patch6:         plymouth_add_RemainAfterExit_yes_to_plymouth_systemd_service.patch
# PATCH-FIX-OPENSUSE plymouth-only_use_fb_for_cirrus_bochs.patch bnc#888590 boo#1172028 bsc#1181913 fvogt@suse.com -- force fb for cirrus and bochs, force drm otherwise. replace removal of framebuffer driver and plymouth-ignore-cirrusdrm.patch with single patch.
Patch7:         plymouth-only_use_fb_for_cirrus_bochs.patch
# PATCH-FIX-UPSTREAM 0001-Add-label-ft-plugin.patch boo#959986 fvogt@suse.com -- add ability to output text in initrd needed for encryption.
Patch1000:      0001-Add-label-ft-plugin.patch
# PATCH-FIX-UPSTREAM 0002-Install-label-ft-plugin-into-initrd-if-available.patch boo#959986 fvogt@suse.com -- add ability to output text in initrd needed for encryption.
Patch1001:      0002-Install-label-ft-plugin-into-initrd-if-available.patch
# PATCH-FIX-UPSTREAM 0003-fix_null_deref.patch boo#959986 fvogt@suse.com -- add ability to output text in initrd needed for encryption.
Patch1002:      0003-fix_null_deref.patch
BuildRequires:  automake
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  gcc
BuildRequires:  kernel-headers
BuildRequires:  libtool
BuildRequires:  libxslt
BuildRequires:  module-init-tools
BuildRequires:  pkgconfig
BuildRequires:  suse-module-tools
# needed for systemd-tty-ask-password-agent
BuildRequires:  intltool
BuildRequires:  update-desktop-files
BuildRequires:  xz
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libsystemd) >= 186
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(pango) >= 1.21.0
BuildRequires:  pkgconfig(systemd) >= 186
%if %{with x11_renderer}
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.14.0
%endif
Recommends:     %{name}-lang
Requires:       %{name}-branding
Requires:       gnu-unifont-bitmap-fonts
Requires:       systemd >= 186
Requires(post): coreutils
Requires(post): plymouth-scripts = %{version}
Requires(postun): coreutils
Recommends:     plymouth-plugin-label-ft
Suggests:       plymouth-plugin-label
Provides:       bootsplash = 3.5
Obsoletes:      bootsplash < 3.5
Provides:       systemd-plymouth = 44-10.2
Obsoletes:      systemd-plymouth <= 44-10.1

%description
Plymouth provides an attractive graphical boot animation in
place of the text messages that normally get shown.  Text
messages are instead redirected to a log file for viewing
after boot.

%package -n libply-boot-client%{soversion}
Summary:        Plymouth core library
Group:          Development/Libraries/C and C++

%description -n libply-boot-client%{soversion}
This package contains the libply-boot-client library used by Plymouth.

%package -n libply-splash-core%{soversion}
Summary:        Plymouth core library
Group:          Development/Libraries/C and C++

%description -n libply-splash-core%{soversion}
This package contains the libply-splash-core library
used by graphical Plymouth splashes.

%package -n libply-splash-graphics%{soversion}
Summary:        Plymouth graphics libraries
Group:          Development/Libraries/C and C++
BuildRequires:  libpng-devel

%description -n libply-splash-graphics%{soversion}
This package contains the libply-splash-graphics library
used by graphical Plymouth splashes.

%package -n libply%{soversion}
Summary:        Plymouth core library
Group:          Development/Libraries/C and C++
Requires:       libply-boot-client%{soversion} = %{version}

%description -n libply%{soversion}
This package contains the libply library used by Plymouth.

%package branding-upstream
Summary:        default configuration file and branding from the Plymouth upstream.
Group:          System/Base
Provides:       %{name}-branding = %{version}-%{release}.
Conflicts:      %{name}-branding
BuildArch:      noarch

%description branding-upstream
This package contains the /usr/share/plymouthd.defaults which contains the basic 
settings and branding from the upstream.

%package devel
Summary:        Libraries and headers for writing Plymouth splash plugins
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
%if %{with x11_renderer}
Requires:       %{name}-x11-renderer = %{version}
%endif
Requires:       libply%{soversion} = %{version}
Requires:       libply-boot-client%{soversion} = %{version}
Requires:       libply-splash-core%{soversion} = %{version}
Requires:       libply-splash-graphics%{soversion} = %{version}
Requires:       pkgconfig

%description devel
This package contains the libply and libplybootsplash libraries
and headers needed to develop 3rd party splash plugins for Plymouth.

%package dracut
Summary:        Plymouth related utilities for dracut
Group:          System/Base
Requires:       %{name} = %{version}
Supplements:    packageand(plymouth:dracut)

%description dracut
This package contains utilities that integrate dracut with Plymouth

%package x11-renderer
Summary:        Plymouth X11 renderer
Group:          System/Base
Requires:       %{name} = %{version}

%description x11-renderer
This package provides the X11 renderer which allows to test plymouth
behavior on environments with a valid DISPLAY.

%package scripts
Summary:        Plymouth related scripts
Group:          System/Base
Requires:       coreutils
Requires:       cpio
Requires:       dracut
Requires:       findutils
Requires:       gzip
Requires(pre):  %{name} = %{version}

%description scripts
This package contains scripts that help integrate Plymouth with
the system.

%package plugin-label
Summary:        Plymouth label plugin
Group:          System/Base
Requires:       libply-splash-graphics%{soversion} = %{version}

%description plugin-label
This package contains the label control plugin for
Plymouth. It provides the ability to render text on
graphical boot splashes using pango and cairo.

%package plugin-label-ft
Summary:        Plymouth FreeType label plugin
Group:          System/Base
Requires:       fontconfig
Requires:       libply-splash-graphics%{soversion} = %{version}

%description plugin-label-ft
This package contains the label control plugin for
Plymouth. It provides the ability to render text on
graphical boot splashes using FreeTyoe

%package plugin-fade-throbber
Summary:        Plymouth "Fade-Throbber" plugin
Group:          System/Base
Requires:       libply%{soversion} = %{version}
Requires:       libply-splash-core%{soversion} = %{version}
Requires:       libply-splash-graphics%{soversion} = %{version}

%description plugin-fade-throbber
This package contains the "Fade-In" boot splash plugin for
Plymouth. It features a centered image that fades in and out
while other images pulsate around during system boot up.

%package plugin-throbgress
Summary:        Plymouth "Throbgress" plugin
Group:          System/Base
Requires:       %{name}-plugin-label = %{version}
Requires:       libply%{soversion} = %{version}
Requires:       libply-splash-core%{soversion} = %{version}
Requires:       libply-splash-graphics%{soversion} = %{version}

%description plugin-throbgress
This package contains the "throbgress" boot splash plugin for
Plymouth. It features a centered logo and animated spinner that
spins repeatedly while a progress bar advances at the bottom of
the screen.

%package plugin-space-flares
Summary:        Plymouth "space-flares" plugin
Group:          System/Base
Requires:       %{name}-plugin-label = %{version}
Requires:       libply%{soversion} = %{version}
Requires:       libply-splash-core%{soversion} = %{version}
Requires:       libply-splash-graphics%{soversion} = %{version}

%description plugin-space-flares
This package contains the "space-flares" boot splash plugin for
Plymouth. It features a corner image with animated flares.

%package plugin-two-step
Summary:        Plymouth "two-step" plugin
Group:          System/Base
Requires:       libply%{soversion} = %{version}
Requires:       libply-splash-core%{soversion} = %{version}
Requires:       libply-splash-graphics%{soversion} = %{version}
Requires:       plymouth-plugin-label = %{version}

%description plugin-two-step
This package contains the "two-step" boot splash plugin for
Plymouth. It features a two phased boot process that starts with
a progressing animation synced to boot time and finishes with a
short, fast one-shot animation.

%package plugin-script
Summary:        Plymouth "script" plugin
Group:          System/Base
Requires:       libply%{soversion} = %{version}
Requires:       libply-splash-core%{soversion} = %{version}
Requires:       libply-splash-graphics%{soversion} = %{version}

%description plugin-script
This package contains the "script" boot splash plugin for
Plymouth. It features an extensible, scriptable boot splash
language that simplifies the process of designing custom
boot splash themes.

%package plugin-tribar
Summary:        Plymouth "script" plugin
Group:          System/Base
Requires:       libply%{soversion} = %{version}
Requires:       libply-splash-core%{soversion} = %{version}
Requires:       libply-splash-graphics%{soversion} = %{version}

%description plugin-tribar
This package contains the "tribar" boot splash plugin for
Plymouth. It features an extensible, scriptable boot splash
language that simplifies the process of designing custom
boot splash themes.

%package theme-fade-in
Summary:        Plymouth "Fade-In" theme
Group:          System/Base
Requires:       %{name}-plugin-fade-throbber = %{version}
Requires:       plymouth-plugin-label = %{version}
Requires(post): %{name}-scripts
BuildArch:      noarch

%description theme-fade-in
This package contains the "Fade-In" boot splash theme for
Plymouth. It features a centered logo that fades in and out
while stars twinkle around the logo during system boot up.

%package theme-spinfinity
Summary:        Plymouth "Spinfinity" theme
Group:          System/Base
Requires:       %{name}-plugin-throbgress = %{version}
Requires(post): %{name}-scripts
Requires(pre):  %{name}
BuildArch:      noarch

%description theme-spinfinity
This package contains the "Spinfinity" boot splash theme for
Plymouth. It features a centered logo and animated spinner that
spins in the shape of an infinity sign.

%package theme-spinner
Summary:        Plymouth "Spinner" theme
Group:          System/Base
Requires:       %{name}-plugin-two-step = %{version}
Requires(post): %{name}-scripts
BuildArch:      noarch

%description theme-spinner
This package contains the "spinner" boot splash theme for
Plymouth.

%package theme-solar
Summary:        Plymouth "Solar" theme
Group:          System/Base
Requires:       %{name}-plugin-space-flares = %{version}
Requires(post): %{name}-scripts
BuildArch:      noarch

%description theme-solar
This package contains the "Solar" boot splash theme for
Plymouth. It features a blue flamed sun with animated solar flares.

%package theme-tribar
Summary:        Plymouth "Tribar" theme
Group:          System/Base
Requires:       %{name}-plugin-tribar = %{version}
Requires(post): %{name}-scripts
BuildArch:      noarch

%description theme-tribar
This package contains the "Tribar" boot splash theme for
Plymouth

%package theme-script
Summary:        Plymouth "Script" theme
Group:          System/Base
Requires:       %{name}-plugin-script = %{version}
Requires(post): %{name}-scripts
BuildArch:      noarch

%description theme-script
This package contains the "script" boot splash theme for
Plymouth. It is a simple example theme the uses the "script"
plugin.

%package theme-bgrt
Summary:        Plymouth "bgrt" theme
# Uses images from spinner theme
Group:          System/Base
Requires:       %{name}-plugin-two-step = %{version}
Requires:       %{name}-theme-spinner = %{version}
Requires(post): %{name}-scripts
BuildArch:      noarch

%description theme-bgrt
This package contains the "bgrt" boot splash theme for
Plymouth. 

%prep
%setup -q
%autopatch -p1
autoreconf -ivf

# replace builddate with patch0date
sed -i "s/__DATE__/\"$(stat -c %%y %{_sourcedir}/%{name}.changes)\"/" src/main.c

%build
%configure \
           --enable-systemd-integration                          \
           --enable-tracing                                      \
           --disable-silent-rules                                \
           --disable-static                                      \
           --disable-upstart-monitoring                          \
           --disable-tests                                       \
           --disable-libkms                                      \
%if %{without x11_renderer}
           --disable-gtk                                         \
%endif
           --with-release-file=%{_sysconfdir}/os-release         \
           --with-boot-tty=/dev/tty7                             \
           --with-shutdown-tty=/dev/tty1                         \
           --with-background-start-color-stop=0x1A3D1F           \
           --with-background-end-color-stop=0x4EA65C             \
           --with-background-color=0x3391cd                      \
           --without-rhgb-compat-link                            \
           --without-system-root-install                         

make %{?_smp_mflags}

%install
%make_install
rm -f %{buildroot}/%{_bindir}/rhgb-client

#Link the plymouth client binary also to /bin until the move to /usr is completed
mkdir %{buildroot}/bin
(cd %{buildroot}/bin; ln -s ..%{_bindir}/plymouth)

# Glow isn't quite ready for primetime
rm -rf %{buildroot}%{_datadir}/plymouth/glow/
rm -rf %{buildroot}%{_datadir}/plymouth/themes/glow/
rm -f %{buildroot}%{_libdir}/plymouth/glow.so

find %{buildroot} -type f -name "*.la" -delete -print

mkdir -p %{buildroot}%{_localstatedir}/lib/plymouth
mkdir -p %{buildroot}/run/plymouth
mkdir -p %{buildroot}%{_localstatedir}/log
touch %{buildroot}%{_localstatedir}/log/boot.log
touch %{buildroot}%{_localstatedir}/spool/plymouth/boot.log
cp $RPM_SOURCE_DIR/boot-duration %{buildroot}%{_datadir}/plymouth/default-boot-duration
cp $RPM_SOURCE_DIR/boot-duration %{buildroot}%{_localstatedir}/lib/plymouth

# We will nolonger ship plymouthd.conf, Plymouthd will read /usr/share/plymouth/plymouthd.defaults if /etc/plymouth/plymouthd.conf doesn't exist(jsc#SLE-11637).
rm -f  %{buildroot}%{_sysconfdir}/plymouth/plymouthd.conf
rm -f  %{buildroot}%{_datadir}/plymouth/plymouthd.conf

%post
%{?regenerate_initrd_post}
if [ ! -e /.buildenv ]; then
   [ -f %{_localstatedir}/lib/plymouth/boot-duration ] || cp -f %{_datadir}/plymouth/default-boot-duration %{_localstatedir}/lib/plymouth/boot-duration
fi
[ -x /bin/systemctl ] && /bin/systemctl daemon-reload >/dev/null 2>&1 || :

%postun
%{?regenerate_initrd_post}
if [ $1 -eq 0 ]; then
    rm -f %{_libdir}/plymouth/default.so
    rm -f /boot/initrd-plymouth.img
    [ -x /bin/systemctl ] && /bin/systemctl daemon-reload >/dev/null 2>&1 || :
fi

%posttrans
%{?regenerate_initrd_posttrans}

%post -n libply-boot-client%{soversion} -p /sbin/ldconfig
%postun -n libply-boot-client%{soversion} -p /sbin/ldconfig
%post -n libply-splash-core%{soversion} -p /sbin/ldconfig
%postun -n libply-splash-core%{soversion} -p /sbin/ldconfig
%post -n libply-splash-graphics%{soversion} -p /sbin/ldconfig
%postun -n libply-splash-graphics%{soversion} -p /sbin/ldconfig
%post -n libply%{soversion} -p /sbin/ldconfig
%postun -n libply%{soversion} -p /sbin/ldconfig
%post theme-spinfinity
if [ $1 -eq 1 ]; then
  set -x
  export LIB=%{_libdir}
  OTHEME="$(%{_sbindir}/plymouth-set-default-theme)"
  if [ "$OTHEME" = "text" ]; then
     if [ ! -e /.buildenv ]; then
       %{_sbindir}/plymouth-set-default-theme -R spinfinity
     else
       %{_sbindir}/plymouth-set-default-theme spinfinity
     fi
  fi
fi

%postun theme-spinfinity
if [ $1 -eq 0 ]; then
    export LIB=%{_libdir}
    if [ "$(%{_sbindir}/plymouth-set-default-theme)" = "spinfinity" ]; then
        %{_sbindir}/plymouth-set-default-theme -R --reset
    fi
fi

%post theme-fade-in
if [ $1 -eq 1 ]; then
  set -x
  export LIB=%{_libdir}
  OTHEME="$(%{_sbindir}/plymouth-set-default-theme)"
  if [ "$OTHEME" = "text" ]; then
     if [ ! -e /.buildenv ]; then
       %{_sbindir}/plymouth-set-default-theme -R fade-in
     else
       %{_sbindir}/plymouth-set-default-theme fade-in
     fi
  fi
fi

%postun theme-fade-in
if [ $1 -eq 0 ]; then
    export LIB=%{_libdir}
    if [ "$(%{_sbindir}/plymouth-set-default-theme)" = "fade-in" ]; then
        %{_sbindir}/plymouth-set-default-theme -R --reset
    fi
fi

%post theme-solar
if [ $1 -eq 1 ]; then
  set -x
  export LIB=%{_libdir}
  OTHEME="$(%{_sbindir}/plymouth-set-default-theme)"
  if [ "$OTHEME" = "text" ]; then
     if [ ! -e /.buildenv ]; then
       %{_sbindir}/plymouth-set-default-theme -R solar
     else
       %{_sbindir}/plymouth-set-default-theme solar
     fi
  fi
fi

%postun theme-solar
if [ $1 -eq 0 ]; then
    export LIB=%{_libdir}
    if [ "$(%{_sbindir}/plymouth-set-default-theme)" = "solar" ]; then
        %{_sbindir}/plymouth-set-default-theme -R --reset
    fi
fi

%files
%license COPYING
%doc AUTHORS NEWS README
%dir %{_datadir}/plymouth
%dir %{_datadir}/plymouth/themes
%dir %{_datadir}/plymouth/themes/details
%dir %{_datadir}/plymouth/themes/text
%dir %{_localstatedir}/lib/plymouth
%dir %{_libdir}/plymouth
%dir %{_libdir}/plymouth/renderers
%dir %{_sysconfdir}/plymouth
%ghost %{_sysconfdir}/plymouth/plymouthd.conf
%{plymouthdaemon_execdir}/plymouthd
%{plymouthclient_execdir}/plymouth
/bin/plymouth
%{_libdir}/plymouth/details.so
%{_libdir}/plymouth/text.so
%{_libdir}/plymouth/renderers/drm*
%{_libdir}/plymouth/renderers/frame-buffer*
%{_datadir}/plymouth/default-boot-duration
%{_datadir}/plymouth/themes/details/details.plymouth
%{_datadir}/plymouth/themes/text/text.plymouth
%{_datadir}/plymouth/bizcom.png
%ghost /run/plymouth
%{_localstatedir}/spool/plymouth
%{_mandir}/man?/*
%ghost %{_localstatedir}/lib/plymouth/boot-duration
%{_unitdir}/*
%ghost %{_localstatedir}/log/boot.log
/usr/share/locale/

%files branding-upstream
%{_datadir}/plymouth/plymouthd.defaults

%files dracut
%{_libexecdir}/plymouth/plymouth-populate-initrd
%{_libexecdir}/plymouth/plymouth-generate-initrd

%files devel
%{plymouth_libdir}/libply.so
%{plymouth_libdir}/libply-splash-core.so
%{_libdir}/libply-boot-client.so
%{_libdir}/libply-splash-graphics.so
%{_libdir}/pkgconfig/ply-splash-core.pc
%{_libdir}/pkgconfig/ply-splash-graphics.pc
%{_libdir}/pkgconfig/ply-boot-client.pc
%{_includedir}/plymouth-1

%files -n libply-boot-client%{soversion}
%{_libdir}/libply-boot-client.so.%{soversion}*

%files -n libply-splash-core%{soversion}
%{plymouth_libdir}/libply-splash-core.so.%{soversion}*

%files -n libply-splash-graphics%{soversion}
%{_libdir}/libply-splash-graphics.so.%{soversion}*

%files -n libply%{soversion}
%{plymouth_libdir}/libply.so.%{soversion}*

%files scripts
%dir %{_libexecdir}/plymouth
%{_sbindir}/plymouth-set-default-theme
%{_libexecdir}/plymouth/plymouth-update-initrd

%if %{with x11_renderer}
%files x11-renderer
%{_libdir}/plymouth/renderers/x11*
%endif

%files plugin-label
%{_libdir}/plymouth/label.so

%files plugin-label-ft
%{_libdir}/plymouth/label-ft.so

%files plugin-fade-throbber
%{_libdir}/plymouth/fade-throbber.so

%files theme-fade-in
%dir %{_datadir}/plymouth/themes/fade-in
%{_datadir}/plymouth/themes/fade-in/bullet.png
%{_datadir}/plymouth/themes/fade-in/entry.png
%{_datadir}/plymouth/themes/fade-in/lock.png
%{_datadir}/plymouth/themes/fade-in/star.png
%{_datadir}/plymouth/themes/fade-in/fade-in.plymouth

%files plugin-throbgress
%{_libdir}/plymouth/throbgress.so

%files theme-spinfinity
%dir %{_datadir}/plymouth/themes/spinfinity
%{_datadir}/plymouth/themes/spinfinity/box.png
%{_datadir}/plymouth/themes/spinfinity/bullet.png
%{_datadir}/plymouth/themes/spinfinity/entry.png
%{_datadir}/plymouth/themes/spinfinity/lock.png
%{_datadir}/plymouth/themes/spinfinity/throbber-[0-3][0-9].png
%{_datadir}/plymouth/themes/spinfinity/spinfinity.plymouth

%files plugin-space-flares
%{_libdir}/plymouth/space-flares.so

%files theme-spinner
%dir %{_datadir}/plymouth/themes/spinner
%{_datadir}/plymouth/themes/spinner/*.*

%files theme-solar
%dir %{_datadir}/plymouth/themes/solar
%{_datadir}/plymouth/themes/solar/*.png
%{_datadir}/plymouth/themes/solar/solar.plymouth

%files theme-tribar
%dir %{_datadir}/plymouth/themes/tribar
%{_datadir}/plymouth/themes/tribar/*.*

%files plugin-two-step
%{_libdir}/plymouth/two-step.so

%files plugin-tribar
%{_libdir}/plymouth/tribar.so

%files plugin-script
%{_libdir}/plymouth/script.so

%files theme-script
%dir %{_datadir}/plymouth/themes/script/
%{_datadir}/plymouth/themes/script/*.png
%{_datadir}/plymouth/themes/script/script.script
%{_datadir}/plymouth/themes/script/script.plymouth

%files theme-bgrt
%dir %{_datadir}/plymouth/themes/bgrt
%{_datadir}/plymouth/themes/bgrt/*.*

%changelog
* Tue Apr 27 2021 qzhao@suse.com
- Pickup plymouth-only_use_fb_for_cirrus_bochs.patch: Currently our
  kernel hardware support need this fix, and boo#1172028 will be
  fix seperately (bnc#888590 boo#1172028 bsc#1181913).
* Thu Apr  1 2021 qzhao@suse.com
- Disable plymouth-systemd-KillMode-mixed.patch: Temporary disable
  it, because aarch64 and ppc64le system could not booting in
  release period, and this is only a enhancement with no harm to
  rollback (bnc#1177082, bnc#1182145, bnc#1184087).
* Wed Feb 24 2021 qzhao@suse.com
- Add plymouth-systemd-KillMode-mixed.patch: Backport from upstream
  change plymouth systemd plymouth-start.service KillMode=mixed,
  the old method is unsafe and deprecated (bnc#1177082,
  bnc#1182145).
* Fri Oct 23 2020 qzhao@suse.com
- Add plymouth_add_RemainAfterExit_yes_to_plymouth_systemd_service.patch:
  Porting from upstream to ensure all plymouth's systemd unit files
  to only run once, either during boot or during shutdown/restart
  (bnc#1177072).
* Sat Aug 29 2020 qzhao@suse.com
- Add plymouth-no-longer-modify-conf-to-drop-isopensuse-macro.patch:
  plymouth will use plymouthd.defaults instead of plymouth.conf and
  packge plymouthd.defaults in a seperet RPM. this can avoid change
  SUSE or openSUSE branding section with is_opensuse macro in the
  config file. means this modification can close the leaps gap
  (jsc#SLE-11637).
* Fri Aug 28 2020 qzhao@suse.com
- Update plymouth.spec: Dropping gdm transition because it has
  alreay deprecated by upstream. Removing git build dependency.
* Mon Jun 15 2020 qzhao@suse.com
- Drop plymouth-only_use_fb_for_cirrus_bochs.patch: openSUSE user
  are using emu-5.0.0 on MacOS-X with HVF acceleration, the
  Plymouth theme with script module fails to go to graphic mode
  with this patch(boo#1172028).
* Wed Oct 30 2019 stefan.bruens@rwth-aachen.de
- Avoid inconsistencies in library package names causing unresolvable
  dependencies, replace all soversion occurences with a macro.
* Wed Sep 11 2019 qzhao@suse.com
- Add patch plymouth-avoid-umount-hanging-shutdown.patch:
  To avoid grantpt() call nsslookup, it will hanging system unmount
  /var during shutdown period(bsc#1105688, bsc#1129386,
  bsc#1134660).
* Thu Aug 15 2019 qzhao@suse.com
- Update to version 0.9.5+git20190908+3abfab2:
  * two-step: Deal with buggy firmware which does not pre-rotate the bgrt image
  * configure: bump so name
  * Internationalization: Add zh_HK and zh_TW translations.
  * add delay time to 8 seconds to fit AMD graphic card.
* Mon Aug  5 2019 qzhao@suse.com
- Update plymouth.spec: Disable upstart-monitor compile because it
  only used in Ubuntu/Debian.
* Sun Aug  4 2019 stefan.bruens@rwth-aachen.de
- Update plymouth.spec: Use bcond_with for X11 renderer, cleanup
  syntax.
* Wed Jul 31 2019 qzhao@suse.com
- Update plymouth.spec: obsolete plymouth render plugin for
  Xwindows, Since this plugin will not be used in the production
  environment, and this modify will highly decrease the compilation
  of build requirements.
* Mon Jul  8 2019 qzhao@suse.com
- Update to version 0.9.4+git20190612+9359382:
  * two-step: Add support for firmware-splashes with rotation
    status bits set
  * Regenerate plymouth.pot to add the strings for the new
    firmware-upgrade mode.
* Fri Jun 14 2019 qzhao@suse.com
- Add dependency to dracut for plymouth-scripts(bnc#1138248).
* Tue Jun 11 2019 dimstar@opensuse.org
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Tue Apr  2 2019 hellcp@mailbox.org
- Change default openSUSE theme to bgrt
* Wed Mar 27 2019 qzhao@suse.com
- Update to version 0.9.4+git20190325+b9f2aac:
  * themes: Update spinner and bgrt background settings
  * Translations: Sync translations with zanata
* Sun Mar 24 2019 hellcp@mailbox.org
- Fix theme-bgrt dependencies
  (based on plugin-two-step with images from theme-spinner)
* Tue Mar 12 2019 qzhao@suse.com
- Update to version 0.9.4+git20181219.c8f1256:
  * ply-pixel-buffer: Fix right and bottom edge rendering of
    scaled buffers.
  * Add support for translating the user visible strings in some
    themes
  * Prefix Title and Subtitle theme config keywords with an
    underscore
  * Add new reboot and system-upgrade modes
  * main: Remove private ply_mode_t
  * two-step: Make ProgressBarShowPercentComplete a per mode
    setting
  * plymouthd.defaults: Change default ShowDelay to 0
  * ply-boot-splash: Do not add ply_boot_splash_update_progress
    timeout multiple times
  * logging: Minor log-message fixes.
    Improve logging format.
  * themes: Update spinner and bgrt theme offline updates mode
  * two-step: Add a per mode setting to suppress messages.
    Add progress-bar support.
    Add MessageBelowAnimation option.
    Add per mode settings.
    Drop background_is_bgrt view_t member
  * ply-progress-bar: Allow caller to specify the widgets width and
    height.
    Allow choosing fore- and back-ground color.
    Redraw on percentage update.
  * boot-server: fix type confusion when allocating connection object
  * ply-device-manager: Handle change events for monitor hotplugging.
    Consume all events in one go.
  * drm: Stop limiting preferred-mode picking to UEFI systems.
    Reset mode on display-port connected outputs with a bad
    link-status.
    Implement handle_change_event.
    Ensure heads are mapped before flushing them.
    Allow calling create_heads_for_active_connectors multiple
    times.
    Allow calling ply_renderer_head_add_connector with existing
    connector_id.
    Limit backend->resources lifetime to within query_device.
    Store and keep all the outputs in the backend.
    Add get_output_info helper function
    Stop storing a pointer to drmModeConnector in ply_output_t
    Stop keeing a drmModeConnector instance around.
    Refactor ply_renderer_head_add_connector and
    ply_renderer_head_new
- Rebase 0002-Install-label-ft-plugin-into-initrd-if-available.patch
* Wed Jan  2 2019 qzhao@suse.com
- Update to version 0.9.4+git20181219.c8f1256:
  * two-step: Use plymouth_strtod
    Use the locale agnostic plymouth_strtod helper which always
    uses a "." as decimal seperator. This fixes the various
    Alignment options not working with some locales.
* Wed Dec 12 2018 qzhao@suse.com
- Update to version 0.9.4+git20181209.f7d5bb1:
  * ply-keyboard: Fix compiler warning
  * When a renderer goes away on a udev remove event, free
    keyboards associated with the renderer, before freeing the
    renderer.
  * device-manager: free keyboards when deactivating a renderer
  * keyboard: add helper to get the keyboard's renderer, if
    applicable.
* Wed Dec  5 2018 qzhao@suse.com
- Update to version 0.9.4+git20181204.0cd0613:
  * drm: Pick a controller for unconfigured connectors
  * drm: Drop crtcs for clones for which we've picked different
    modes
  * drm: More connector enumeration refactoring
  * drm: Store tiled and rotation in ply_output_t
  * drm: Refactor create_heads_for_active_connectors
  * drm: Directly store the mode instead of the mode_index
  * drm: Drop unused encoder_id
* Thu Nov 29 2018 qzhao@suse.com
- Update to version 0.9.4+git20181129.a7ec3e6:
  * Add new BGRT theme, using the firmware boot splash as background
  * two-step: bgrt: Deal with quirky firmwares, Add ACPI BGRT
  extension support, Speed up background-tile drawing on HiDPI
  screens, Use a pixel-buffer instead of an image for the view's
  background
  * ply-pixel-buffer: Add ply_pixel_buffer_rotate_upright helper,
  Add ply_pixel_buffer_get/set_device_rotation helpers, Fix marking
  buffers as opaque when doing a solid fill, Fix fill_with_buffer
  fastpath when device_scale != 1.
* Fri Nov 23 2018 qzhao@suse.com
- Update to version 0.9.4+git20181122.aaa140b:
  Add a separator between different boot logs
  Fix race causing undesired creation of non-gfx devs
  Fix animation not starting on later added heads
* Mon Nov 12 2018 qzhao@suse.com
- Update to version 0.9.4+git20181111.118c5ca:
  Modify systemd-units: Add "ConditionVirtualization=!container" in
  all plymouth-*.service, also systemd-ask-password-plymouth.path.
* Tue Nov  6 2018 qzhao@suse.com
- Update to version 0.9.4+git20181105.f898586:
  bump to 0.9.4
* Wed Oct 31 2018 qzhao@suse.com
- Update to version 0.9.3+git20181031.025ce59:
  drm: use preferred mode for outputs
  drm: Refactor ply_renderer_connector_get_rotation
  drm: Reset LUT/gamma table before the first drmModeSetCrtc call
  libply: Move kernel commandline parsing functions to libply/ply-utils
  throbber: Don't skip last frame when waiting for end.
- Drop plymouth-throbber-Don-t-skip-last-frame-when-waiting-for-end.patch
  * Upstream has already accept Michal's modification.
* Tue Oct 23 2018 msrb@suse.com
- plymouth-throbber-Don-t-skip-last-frame-when-waiting-for-end.patch
  * Make sure plymouthd stops throbber animation at the first
    opportunity after receiving quit command, instead of looping
    multiple times. (boo#1110199)
* Thu Oct 18 2018 qzhao@suse.com
- Update to version 0.9.3+git20180827.0a66272:
  * boot-server: free the argument and triggers
  * event-loop: fix leak in error path
  * script: fix various memory leaks
  * key-file: ply_key_file_get_value returns duplicated memory, fix
    memory leaks.
  * event-loop: fix leak in error path
  * boot-splash: fix memory leak in error path
  * populate-initrd: drop unused local variable
* Tue Aug 28 2018 qzhao@suse.com
- Update to version 0.9.3+git20180827.0a66272:
  ensure tty is closed on deactivate
  If plymouth doesn't get explicitly "activated" then when
  GDM tries to deactivate it, the deactivation request is
  a noop.
  One aspect of being active, though is having ownership and
  control of the terminal.  This happens immediately, even
  before a splash is shown.
  The `deactivate` request needs to relinguish such control,
  unconditionally, since some display server is about to use
  the tty.
- Update patch name base on quilt standerd
  Remove only_use_fb_for_cirrus_bochs.patch
  Add plymouth-only_use_fb_for_cirrus_bochs.patch
  Remove 0001-Some-greenish-openSUSE-colors.patch
  Add plymouth-some-greenish-openSUSE-colors.patch
* Fri Aug 17 2018 bjorn.lie@gmail.com
- Update to version 0.9.3+git20180807.7663b0c:
  * systemd-units: Add "ConditionVirtualization=!container"
  * README: add link to Code of Conduct
  * two-step: add unhandled splash mode case to switch
  * main: fix build
  * Fix miscellaneous compiler warnings
  * configure: Pass -Wno-cast-function-type if available
  * main: Fix getting detailed logs from systemd
  * main: Show details when ESC is pressed during splash_delay
  * drm: Remove unnecessary reset_scan_out_buffer_if_needed() call
    from ply_renderer_head_map()
  * main: Only activate renderers if the splash uses pixel-displays
- Switch to new gitlab home in _service.
- Refresh patches with quilt.
- Use autosetup macro.
* Sat Aug  4 2018 qzhao@suse.com
- Drop plymouth-fix-window-size: The use of the smallest screen
  size is deliberate (boo#804607 bsc#894051).
* Wed Apr 11 2018 oholecek@suse.com
- Modify 0001-Add-label-ft-plugin.patch to fix problems with
  multiline text (bsc#1083695)
  * to prevent infinite loop newline characters need to be skipped
- Use %%license instead of %%doc (bsc#1082318)
* Sat Jan 13 2018 zaitor@opensuse.org
- Update to version 0.9.3+git20171220.6e9e95d:
  * device-manager: drop superfluous
    create_pixel_displays_for_renderer call
  * x11: don't call gdk_display_get_name before gtk_init
* Mon Dec  4 2017 zaitor@opensuse.org
- Update to version 0.9.3+git20171130.fa66a5b:
  * INSTALL: Fix a spelling error in the command example
  * populate-initrd: handle themes with subdirs
  * device-manager: fall back to text mode if graphical devices
    fail
  * scripts: Use >&2 instead of /dev/stderr
  * terminal: add include for sysmacros.h
  * configure: bump to 0.9.4
  * terminal-session: don't delete boot.log
  * Revert "Make boot.log world readable by default"
- Rebase 0002-Install-label-ft-plugin-into-initrd-if-available.patch
* Wed Nov 29 2017 qzhao@suse.com
- Drop stop-graphical.patch: There are no conflicting these days,
  obsolete this patch to enable auto switch to TTY when display
  server not exist (boo#1066510).
* Wed Jun 14 2017 qzhao@suse.com
- Update plymouth.spec: Add COPYING file in plymouth package file
  list, This is for the law requirement (bsc#1043834).
* Mon May  8 2017 antoine.belvire@opensuse.org
- Update to version 0.9.2+git20170424.6fd5c6b:
  * main: Look for config in runtime dir first
  * main: Look for theme in runtime dir first
  * Revert "Recreate boot log at each boot instead of appending"
  * x11: implement get_display_name
  * drm: implement get_display_name
  * configure: don't look for libudev when --without-udev is passed
  * renderer: export device name from plugin
  * device-manager: handle NULL renderer better
- Remove 0001-device-manager-handle-NULL-renderer-better.patch
  (upstreamed).
* Thu Jan 26 2017 zaitor@opensuse.org
- Drop use-mkinitrd.patch: No longer needed, mkinitrd is just a
  wrapper for dracut now any way, hence this patch is currently
  pointless.
* Wed Jan 25 2017 fvogt@suse.com
- Remove patch which causes breakage with systemd-vconsole-setup (bsc#1020327):
  * 0001-let-it-become-a-real-daemon.patch
- Add upstream patch to fix crash on boot:
  * 0001-device-manager-handle-NULL-renderer-better.patch
- Replace removal of framebuffer driver and plymouth-ignore-cirrusdrm.patch
  with single patch:
  * only_use_fb_for_cirrus_bochs.patch
* Mon Jan  9 2017 zaitor@opensuse.org
- Update to version 0.9.2+git20161215.18dd755:
  * terminal: refresh geometry after drm device arrives
  * logger: stop using carriage returns
  * build-goo: don't install systemd units during distcheck
  * systemd-units: Fix uninstall script
  * configure: switch to tar.xz instead tar.bz2
  * libply: fix HiDPI detection
  * libply, main: Add device scale setting
  * main: support plymouth.force-scale on the kernel command line
  * build-goo: make udev support build time optional
  * device-manager: dont pass terminal as renderer device
* Tue Sep  6 2016 tchvatal@suse.com
- Update to version 0.9.2+git20160823.e4b7e49:
  * libply: fix HiDPI detection
  * libply, main: Add device scale setting
  * main: support plymouth.force-scale on the kernel command line
- Refresh patch:
  * 0001-let-it-become-a-real-daemon.patch
* Tue Sep  6 2016 tchvatal@suse.com
- Add systemd to buildrequires to properly detect systemd-ask-password
* Thu Aug  4 2016 tchvatal@suse.com
- Sort out with spec-cleaner and move all buildrequires to main scope
  not to subpkgs, sometimes interpreted wrongly by rpm if it is split
* Thu Aug  4 2016 tchvatal@suse.com
- Reduce patches list removing merged upstream (bit differently tho):
  * 0001-seats-guard-against-NULL-terminal.patch
  * fix-serial-consoles.patch
  * plymouth-boot-vga-framebuffer.patch
- Refresh patches:
  * 0001-let-it-become-a-real-daemon.patch
- Update to version 0.9.2+git20160620.0e65b86:
  * configure: tweak defaults to be more systemd friendly
  * text: don't draw if not animating
  * terminal: always open terminal in non-blocking mode
  * device-manager: probe existing DRM devices at startup
  * drm: don't pick up drm master implicitly
  * terminal: refresh geometry after drm device arrives
  * logger: stop using carriage returns
  * build-goo: don't install systemd units during distcheck
  * systemd-units: Fix uninstall script
  * configure: switch to tar.xz instead tar.bz2
* Wed Jun  1 2016 idonmez@suse.com
- Remove framebuffer support bsc#980750 and bsc#982226
* Mon Feb  8 2016 fvogt@suse.com
- Add 0003-fix_null_deref.patch as well
  - Avoid potential SEGV if label plugin fails to load
* Wed Jan 20 2016 fvogt@suse.com
- Add 0001-Add-label-ft-plugin.patch and
    0002-Install-label-ft-plugin-into-initrd-if-available.patch:
  - Ability to output text in initrd, needed for encryption
  - boo#959986
* Mon Dec 28 2015 dimstar@opensuse.org
- Update to version 0.9.2:
  + two-step: Add separate startup / shutdown animations.
  + device-manager: try fb device if drm device failed.
  + Port to GTK+ 3.0.
  + script support system update events.
  + Drop the obsolete log-viewer
- Rebase patches:
  + plymouth-fix-window-size
  + stop-graphical.patch
  + 0001-Some-greenish-openSUSE-colors.patch
  + fix-serial-consoles.patch
  + 0001-seats-guard-against-NULL-terminal.patch
  + plymouth-ignore-cirrusdrm.patch
  + plymouth-boot-vga-framebuffer.patch
  + 0001-let-it-become-a-real-daemon.patch
- Drop upstream fixed patches:
  + 0001-device-manager-only-call-ply_terminal_free.patch
  + 0001-splash-remove-pixel_pixel-in-sprite-lib-when-notifie.patch
  + 0001-splash-do-not-process-display-lists-if-it-is-empty.patch
  + 0001-libply-splash-core-also-monitor-for-file-removal-in-.patch
  + 0001-seat-be-a-little-more-forgiving-in-the-case-there-s-.patch
  + 0001-text-step-bar-use-correct-utf-8-multibyte-sequence-f.patch
- Replace pkgconfig(gtk+-2.0) BuildRequires with
  pkgconfig(gtk+-3.0), following upstreams port to GTK+ 3.0.
- Rename library subpackage from *2 to *4, followings upstreams
  soname bump.
- Drop utils subpackage: the log-viewer, which was the only tool
  left, has been dropped.
* Thu Dec 10 2015 tiwai@suse.de
- Fix missing dependency on coreutils for initrd macros (boo#958562)
- Call missing initrd macro at postun (boo#958562)
* Mon Sep 21 2015 idonmez@suse.com
- Use is_opensuse to simplify if/else block
* Fri Sep  4 2015 idonmez@suse.com
- Add a direct dependency on systemd, since we need to know the
  path to systemd-tty-ask-password-agent, fixes part of bsc#943312
* Sat Nov  8 2014 ledest@gmail.com
- fix bashisms in post/postun scripts
* Thu Sep 25 2014 idonmez@suse.com
- Update 0001-let-it-become-a-real-daemon.patch to call setsid
  only from the child process.
* Fri Sep 12 2014 idonmez@suse.com
- Add 0001-let-it-become-a-real-daemon.patch to make plymouth
  a real daemon, fixes part of bnc#889757. Patch by Werner.
* Thu Sep  4 2014 idonmez@suse.com
- Add plymouth-boot-vga-framebuffer.patch to fix boot_vga
  problem with framebuffer devices. (bnc#886211)
* Mon Aug 11 2014 idonmez@suse.com
- Modify plymouth-ignore-cirrusdrm.patch to return as
  early as possible. Patch by glin@suse.com
* Thu Aug  7 2014 idonmez@suse.com
- Invert the logic in plymouth-ignore-cirrusdrm.patch bnc#890516
* Mon Jul 28 2014 fcrozat@suse.com
- Add
  0001-text-step-bar-use-correct-utf-8-multibyte-sequence-f.patch:
  fix incorrect UTF-8 code used for square (bnc#886148).
* Fri Jul 25 2014 fcrozat@suse.com
- Add plymouth-ignore-cirrusdrm.patch: ignore cirrus drm and use fb
  instead (bnc#888590)
* Thu Jul 24 2014 fcrozat@suse.com
- Add
  0001-seat-be-a-little-more-forgiving-in-the-case-there-s-.patch:
  Be more forgiving with empty seat.
* Tue Jul  8 2014 fcrozat@suse.com
- Update 0001-Some-greenish-openSUSE-colors.patch to also use SUSE
  colors on tribar (bnc#886148)
* Fri Jun 27 2014 fcrozat@suse.com
- Add
  0001-libply-splash-core-also-monitor-for-file-removal-in-.patch:
  handle new udev behaviour in seqnum removal.
* Fri Jun 20 2014 fcrozat@suse.com
- Add
  0001-splash-do-not-process-display-lists-if-it-is-empty.patch:
  fix crash when calling plymouth quit
- Add 0001-seats-guard-against-NULL-terminal.patch: guard against
  NULL terminal.
- Update stop-graphical.patch: add RemainAfterExit=true to
  plymouth-start.service, ensuring plymouthd is not restarted when
  switching between runlevels.
* Thu Jun 19 2014 fcrozat@suse.com
- Add
  0001-splash-remove-pixel_pixel-in-sprite-lib-when-notifie.patch:
  fix crash when pixel_display is removed.
- Add 0001-device-manager-only-call-ply_terminal_free.patch: fix
  crash.
- Add use-mkinitrd.patch: call mkinitrd -B, not dracut for now,
  otherwise initramfs is being created by plymouth-update-initrd,
  not initrd file.
- Ensure we don't rebuild initrd twice when updating plymouth.
- Ensure default theme is SLE/openSUSE (based on %%suse_version)
* Fri Jun  6 2014 fcrozat@suse.com
- Release 0.9.0 (3 additional fixes compared to previously packaged
  git snapshot):
  + Use udev for graphics device enumeration
  + Add new text plugin to replace the tribar one
  + Add background tiling and watermark support to two-step
  + Make various plymouth commands that change state be resilient
    to being  called multiple times
  + Support going back to the initrd at shutdown
  + Keyfile parser improvements
  + Make plymouthd use better defaults when running on top of X11
  + Fixes for systems using QXL
  + minor two-step plugin fixes
  + Use /sys/class/tty/console/active instead of parsing
    /proc/cmdline for consoles.
  + Documentation improvements
  + Drop driver specific renderers and use generic driver across the
    board.
  + Better debug message output
  + systemd integration fixes
  + upstart integration fixes
  + initrd scripts fixes
  + Misc fixes
* Thu Jun  5 2014 idonmez@suse.com
- Update fix-serial-consoles.patch to fix a crash in some rare
  cases.
* Wed May 21 2014 idonmez@suse.com
- Add fix-serial-consoles.patch to fix binary garbage on serial
  consoles. This is bnc#873859
* Mon May  5 2014 fcrozat@suse.com
- Remove plymouth-restore-suspend.patch: suspend package is being
  dropped, no longer needs to provide this old API.
- Remove requires on suspend package.
* Thu Apr 17 2014 idonmez@suse.com
- Update to git snapshot as of 20140327
  * Fixes bnc#872502 and bnc#872428
* Wed Apr 16 2014 trenn@suse.de
- Kill all mkinitrd stuff
  Remove suse-initrd-support
- Tell zypper to regenerate initrd on installation/update via %%post and
  %%posttrans scripts
* Thu Apr 10 2014 idonmez@suse.com
- Add plymouth-manpages.patch to fix manpage installation (bnc#871419)
* Thu Feb 20 2014 fcrozat@suse.com
- Drop plymouth.conf, it is no longer used, plymouthd.conf is
  nowadays.
* Sat Feb 15 2014 kigurame@opensuse.org
- Updated from git
- carried over patches
- Dropped 0001-Make-plymouthd-real-daemon-and-save-old-log.patch
  Because it is really not necesary
* Wed Feb 12 2014 werner@suse.de
- Add patch
  0001-Make-plymouthd-real-daemon-and-save-old-log.patch
  all daemons should call setsid(2) to become a real daemons without
  controlling terminal.  Beside this the old boot log will help for
  debugging and for support.
* Thu Dec 12 2013 uweigand@de.ibm.com
- Add powerpc64le-linux support.
* Thu Sep 26 2013 lnussel@suse.de
- disable plymouth in initrd if the root volume is encrypted. This
  is a workaround until plymouth is able to handle the prompt
  correctly (bnc#834063).
* Wed Sep 11 2013 crrodriguez@opensuse.org
- version 0.8.8_git201309032142
- All device specific code has been removed because the kernel
  has been fixed in the meanwhile so plymouth no longer requires
  libdrm_intel, libdrm_radeon, libdrm_nouveau and can use the generic
  interface.
  This commit does not add any new features or bugfixes but removes
  a huge chunk of unnecessary code.
* Fri Aug 16 2013 lmuelle@suse.com
- Pre require plymouth from plymouth-scripts; (bnc#806388).
* Thu Aug  1 2013 tittiatcoke@gmail.com
- Update to version 0.8.8_git201308011340
  - Drop patch plymouth-correct-systemd-prefix.patch
  - Drop patch plymouth-close.patch
  - Drop patch plymouth-close-unredirect.patch
  - Drop patch plymouth-redirect-null.patch
  - Drop patch plymouth-exit-code.patch
  - Drop patch plymouth-terminal-session-close.patch
* Mon Jul 29 2013 tittiatcoke@gmail.com
- Add upstream patch plymouth-correct-systemd-prefix.patch to
  correct the systemd prefixes in some systemd files. This replaces
  the sed string.
* Thu Jun 27 2013 crrodriguez@opensuse.org
- Require pigz instead of gzip
- ensure plugin requires are versioned.
* Sun Jun 16 2013 crrodriguez@opensuse.org
- own %%{_localstatedir}/log/boot.log
  and %%{_localstatedir}/spool/plymouth/boot.log (as %%ghost s)
* Tue Jun 11 2013 fcrozat@suse.com
- Add plymouth-close: do not try to close negative fd.
- Add plymouth-close-unredirect.patch: do not leak fd when stopping
  redirection of /dev/console (bnc#811185)
- Add plymouth-redirect-null.patch: redirect plymouth standard io
  to /dev/null (bnc#811185)
- Add plymouth-exit-code.patch: ignore exit code in ExecStartPost.
- Add plymouth-terminal-session-close.patch: do no try to close
  terminal session fd if already closed.
* Sun May 12 2013 crrodriguez@opensuse.org
- Not only reboot.service is prefixed with systemd- currently
  but also kexec,halt,poweroff.
* Mon Apr 22 2013 crrodriguez@opensuse.org
- Also ensure we express rpm dependencies correctly
  this package is not gonna work on systemd < 186.
* Mon Apr 22 2013 crrodriguez@opensuse.org
- Update to version 0.8.8_git201304161248
- drop plymouth-change-service-name.patch, replaced by
  a sed script that will account for all service files' future changes
- drop patch plymouth-trace-lines, in upstream now
- drop plymouth-udevadm-path.patch, generic solution in upstream now.
- drop ply-sdunitdir.patch likewise.
- drop plymouth-systemd-in-usr.patch likewise.
- drop systemd-no-warning.patch, not needed with newer systemd
- drop plymouth-sd-notforking.patch , not really needed anymore.
* Thu Feb 28 2013 tittiatcoke@gmail.com
- Changed %%post scripts so only the rebuild of the initrd is
  omitted within the build environment
* Fri Feb 22 2013 tittiatcoke@gmail.com
- Added patch plymouth-correct-runtime-dir.patch to make the
  plymouthruntimedir equal to /run/plymouth and not /var/run/plymouth
* Wed Feb  6 2013 fcrozat@suse.com
- Rename plymouth-sd-notforking.patch to fix typo in patch name
- Add plymouth-change-service-name.patch: fix incorrect service
  names used for dependencies. Now use systemd-reboot.service
  (replacing reboot.service) and display-manager.service (replacing
  prefdm.service).
* Tue Dec 18 2012 tittiatcoke@gmail.com
- Make sure that the right version of the scripts is required by
  the main package. This to prevent that an update of the scripts
  is not installed (bnc#793400)
- Removed obsolete patch plymouth-remove-pid-file.patch. Issue
  has been resolved upstream
* Wed Nov 14 2012 seife+obs@b1-systems.com
- fix path to systemd-tty-ask-password-agent for newer systemd
- create the pid file again during boot, the existence of this is
  a condition for systemd-ask-password-plymouth.service. A proper
  fix might look different but that get's it going again.
* Tue Nov  6 2012 tittiatcoke@gmail.com
- Provide the scripts to integrate Plymouth in dracut as a
  separate package.
- Added patch (plymouth-dracut-path.patch) to correct the paths
  inside the specific plymouth-dracut scripts
* Mon Nov  5 2012 crrodriguez@opensuse.org
- Update to an slightly newer git snapshot to fix regression
  from 0.8.8
* Thu Nov  1 2012 crrodriguez@opensuse.org
- Version 0.8.8
  * main: Try to own socket before anything else
  * main: silently succeed if plymouthd is started a second time
  * service: start plymouthd unconditionally
  * x11: make window fullscreen by default
  * x11: only create windows when necessary
* Thu Nov  1 2012 crrodriguez@opensuse.org
- plymoith-sd-notforking.patch: Make plymouthd to not use
  Service type "forking"
- ply-sdunitdir.patch: Must install units in %%{_unitdir} as
  returned by pkg-config not in a hardcoded location.
* Fri Oct 12 2012 tittiatcoke@gmail.com
- Remove the non required font file in /etc/fonts/conf.avail/ .
* Thu Oct 11 2012 tittiatcoke@gmail.com
- Adjusted the upstream patch to remove the pid file. The original
  one seems to cause issues with the DM killing plymouth
* Thu Oct 11 2012 tittiatcoke@gmail.com
- Fix the Pango installation within the initrd. This would
  resolve the error message that Pango cannot find any fonts
* Thu Sep 27 2012 tittiatcoke@gmail.com
- fix the libdir path in plymouth-set-default-theme (bnc#780085)
* Thu Sep 20 2012 tittiatcoke@gmail.com
- Update to version 0.8.7
  + fix plymouth race at bootup breaking efi/vesa handoff
  + Systemd fixes
- Add plymouth-remove-pid-file.patch: remove PID file usage
  (bnc#780976) (Thanks to fcrozat)
- Remove upstream patches: plymouth-systemd-target.patch,
  0001-ply-text-progress-bar-strip-quotes-if-present,patch,
  plymouth-fix-systemd-service.patch, plymouth-after-udev-settle
  due to upstream inclusion.
* Wed Aug 22 2012 fcrozat@suse.com
- Add plymouth-after-udev-settle.patch: ensure plymouth is started
  after udev triggers has been started (git + name change due to
  systemd < 183 in openSUSE 12.2).
* Wed Aug 22 2012 tittiatcoke@gmail.com
- Ensure that the right Pango version is used for copying one of
  the pango modules
* Wed Aug  8 2012 fcrozat@suse.com
- Add plymouth-fix-systemd-service.patch: remove dashes next to
  semi-colons, it confuses systemd. (bnc#774400)
- Update suse-initrd-support to not start plymouth if kernel
  cmdline contains "shell" or "plymouth.enable=0" or
  "rd.plymouth=0".
* Mon Aug  6 2012 dmueller@suse.com
- remove suspend dependency on ARM
* Sun Jul 29 2012 jengelh@inai.de
- Ship /etc/os-release in the initrd so that the pretty name is
  displayed in text-splash mode
- Give the text-splash some SUSE-typical green coloring
* Sun Jul 29 2012 dmueller@suse.com
- fix build for ARM
* Thu Jul 26 2012 tittiatcoke@gmail.com
- Move the openSUSE branding to its rightful place
* Fri Jul 20 2012 fcrozat@suse.com
- Update to 0.8.6.1:
  + Fix systemd path file generation
- Changes from 0.8.6:
  + fix flush_area fast-path
  + seed random number generator by default for script plugins
  + allow plymouth to be built without gtk dependency
  + cope with lack of /etc/os-release better
  + pull in systemd unit files (bnc#770890)
  + add support for new "updates" mode for doing package updates
  (only available for some plugins at the moment)
- Add plymouth-restore-suspend.patch: revert commit removing
  suspend/resume support, needed for suspend package.
- Add plymouth-systemd-target.patch: add missing symlinks to start
  plymouth on shutdown / reboot / kexec (bnc#770764).
- Add plymouth-udevadm-path.patch: adapt to udevadm path on
  openSUSE.
- Ensure systemctl daemon-reload is called in post / postun
- Add systemd-no-warning.patch: remove Documentation tag not
  handled by systemd v44.
- Update stop-graphical.patch to correct prevent plymouth.quit to
  start under runlevel 5 (handled by xdm initscript directly).
* Fri Jul  6 2012 dvaleev@suse.com
- don't require intel_drm on ppc
* Wed Jul  4 2012 meissner@suse.com
- run "/sbin/mkinitrd" and let it figure out by itself
  what initrds to update. bnc#769812
* Mon Jul  2 2012 fcrozat@suse.com
- Provides systemd units, instead of relying on systemd to ship
  them (bnc#769397).
- Ensure plymouth--wait-quit.service conflicts with
  graphical.target.
* Fri Jun 29 2012 tittiatcoke@gmail.com
- Update to 0.8.5.1
  + two-step splash plugin quit fixes
  + add generic driver to drm renderer plugin
    This allows new modesetting drivers to work with plymouth
    automatically
  + fixes for video cards that don't support 32bpp
  + add alignment and width features to label controls
  + new documentation
  + event loop fix
  + more serial console fixes
  + better systemd integration
  + new flush api to client library
  + Allow plymouth to build the drm renderer without the driver
    dependent libdrm_* libraries.
* Thu Jun 21 2012 lnussel@suse.de
- disable plymouth if init is not systemd (could be e.g. /bin/sh or
  sysvinit then)
* Mon Jun 11 2012 coolo@suse.com
- if we provide bootsplash, we should also make sure to obsolete
  its version
* Mon Jun  4 2012 tittiatcoke@gmail.com
- Ensure that the openSUSE theme is default. (bnc#765277)
- Remove unnecessary changes to the kernel options. Plymouth also
  accepts splash=silent.
* Wed May 30 2012 vuntz@opensuse.org
- Add plymouth-scripts Requires(post) to branding-openSUSE
  subpackage, to make sure that the %%post scriptlet will work.
- Make sure we export LIB and not lib in the %%postun scriptlets of
  theme-solar and branding-openSUSE subpackages.
* Tue May 29 2012 tittiatcoke@gmail.com
- Ensure that label.so is being installed for the openSUSE branding
  (bnc#763574)
* Mon May 21 2012 tittiatcoke@gmail.com
- Update the installation/update from plymouth in a way that the
  initrd file for the current running kernel is updated.
- Corrected a typo with regards to the location of a pango module
  when setting up the initrd.
* Tue May 15 2012 tittiatcoke@gmail.com
- Added a patch for openSUSE to enable the rebuild of the initrd
  with the plymouth-set-default-theme script. (bnc#757284)
* Sun May 13 2012 tittiatcoke@gmail.com
- Added plymouth to the requires of plymouth-scripts. This
  should resolve bug (bnc#757284)
* Fri May 11 2012 nmo.marques@gmail.com
- Split x11 renderer into his own package; the x11 renderer allows
  users to test plymouth themes; having it available on the devel
  package will force people who just want to test a theme to
  install a lot of unwanted dependencies. Being on it's own package
  without explicit dependencies provides extra functionality to
  users who want to test themes without having to rebuild initrd
  and rebooting for testing.
- bnc#761403
* Sat Apr 28 2012 tittiatcoke@gmail.com
- Reduce the number of fonts that are included in the initrd. Also
  let mkinitrd sort out the dependencies for the required libs.
- Use the same font as that grub2 is currently using for it's
  graphics mode.
* Tue Apr 17 2012 glin@suse.com
- Correct the theme name in the post install script of
  plymouth-branding-openSUSE
* Thu Apr  5 2012 tittiatcoke@gmail.com
- Updated the initrd patch to include the necessary files to have
  text support (e.g. LUKS passphrase question, etc)
- Temporarily added a openSUSE plymouth theme
  (plymouth-branding-openSUSE) to have a better integration with
  12.2.
* Thu Mar 29 2012 tittiatcoke@gmail.com
- Ensure that both grub and grub2 are adjusted with regards to the
  splash parameter. Running grub2-mkconfig to have the right
  configuration.
- Installation of themes are not causing any reset of the selected
  default theme anymore. Now this only happens when a theme is
  installed and the default theme is set to TEXT.
* Sun Mar 25 2012 tittiatcoke@gmail.com
- Update to the official release of 0.8.4
  * Bugfix:  Use /dev/fb0 instead of /dev/fb, this resolves the
    issue of not showing the splash during shutdown
* Fri Mar  9 2012 tittiatcoke@gmail.com
- Add a small change in order to have plymouth activated with Grub2
* Thu Feb 23 2012 tittiatcoke@gmail.com
- Make sure that the package libply-boot-client is always
  installed to prevent a system that will not boot
* Thu Feb 23 2012 saschpe@suse.de
- Replaced package core-libs with individual packages for each shared
  library (SLPP)
- Proper provides/obsoletes pair for bootsplash
- Could not resist to run spec-cleaner ;-)
* Tue Feb 21 2012 tittiatcoke@gmail.com
- Changed the parameters to plymouthd in the initrd to create
  the necessary pid-file for the systemd integration
* Fri Feb 17 2012 tittiatcoke@gmail.com
- Ensure that /bin/plymouth still is available as that the
  displaymanagers (KDM/GDM) are expecting this. This needs to be
  in place until the migration to /usr is completed.
* Fri Feb 17 2012 tittiatcoke@gmail.com
- Finalize the Plymouth integration on openSUSE.
  * Current default theme is Solar with the openSUSE Geecko
  * Plymouth bootsplash will run on tty7 during boot.
  * Install all files in /usr
* Tue Dec 27 2011 crrodriguez@opensuse.org
- Update to current git
* Wed Mar 23 2011 jeffm@suse.de
- Update to git snapshot from 12 Mar 2011.
  - Mostly minor fixes.
* Sat Feb  5 2011 jeffm@suse.de
- Updated to latest snapshot.
  - boot-server: improve debug output
  - pixel-buffer: Fix overflow in blend_two_pixel_values
  - boot-server: fix debug output when message is from init
- Fixed an issue with the script plugin's Window attributes returning
  the size of the smallest display when multiple displays are used.
* Wed Dec 29 2010 jeffm@suse.de
- Fixed location of text.so and details.so in plymouth-scripts
* Wed Dec 22 2010 seife+obs@b1-systems.com
- fix the build failure:
  - own additional directories
- fix rpmlint failures:
  - fix up package groups - those are just guessed sometimes
  - rename plymouth-graphics-libs to libply-splash-graphics2
    (this one was fatal)
  - do not own /var/run/plymouth - probably still needs fixing
    (this was almost fatal)
  - do not include build date in binary, use mtime of source
    patchfile instead
* Wed Dec  8 2010 jeffm@suse.de
- Initial packaging.
